package com.company.hidedropdown.app;

import com.vaadin.flow.component.button.ButtonVariant;
import com.vaadin.flow.component.orderedlayout.HorizontalLayout;
import io.jmix.flowui.component.genericfilter.Configuration;
import io.jmix.flowui.component.genericfilter.GenericFilter;
import io.jmix.flowui.kit.component.KeyCombination;
import io.jmix.flowui.kit.component.button.JmixButton;
import org.springframework.lang.Nullable;

import java.util.Objects;

public class MyGenericFilter extends GenericFilter {

    protected JmixButton myApplyButton;

    @Override
    protected void initControlsLayout(HorizontalLayout controlsLayout) {
        controlsLayout.setWidthFull();
        controlsLayout.setClassName(FILTER_CONTROLS_LAYOUT_CLASS_NAME);

        myApplyButton = createMyApplyButton();
        initMyApplyButton(myApplyButton);
        controlsLayout.add(myApplyButton);

        settingsButton = createSettingsButton();
        initSettingsButton(settingsButton);
        controlsLayout.add(settingsButton);

        addConditionButton = createAddConditionButton();
        initAddConditionButton(addConditionButton);
        controlsLayout.add(addConditionButton);
    }

    protected JmixButton createMyApplyButton() {
        return uiComponents.create(JmixButton.class);
    }

    protected void initMyApplyButton(JmixButton button) {
        button.addClickListener(__ -> getDataLoader().load());
        button.addThemeVariants(ButtonVariant.LUMO_SUCCESS, ButtonVariant.LUMO_PRIMARY);
        button.setShortcutCombination(KeyCombination.create(applyShortcut, this));

        updateApplyButtonText(isAutoApply());
    }

    @Override
    protected void updateApplyButtonText(boolean autoApply) {
        String text = autoApply
                ? messages.getMessage("genericFilter.applyButton.autoApply")
                : messages.getMessage("genericFilter.applyButton");
        myApplyButton.setText(text);
    }

    @Override
    @Nullable
    public KeyCombination getApplyShortcut() {
        return myApplyButton.getShortcutCombination();
    }

    @Override
    public void setApplyShortcut(@Nullable String applyShortcut) {
        if (!Objects.equals(this.applyShortcut, applyShortcut)) {
            this.applyShortcut = applyShortcut;

            myApplyButton.setShortcutCombination(KeyCombination.create(applyShortcut, this));
        }
    }

    @Override
    protected void updateSelectConfigurationDropdown() {
        // do nothing
    }

    @Override
    protected void addSelectConfigurationAction(Configuration configuration) {
        // do nothing
    }
}
